diff --git a/gso/services/subscriptions.py b/gso/services/subscriptions.py
index 97474c7ada572fbb25e18481db0b57e5ebefd872..ead378a771c4ac5d1408fe9c1f78770e1a0a5b70 100644
--- a/gso/services/subscriptions.py
+++ b/gso/services/subscriptions.py
@@ -192,13 +192,13 @@ def get_active_subscriptions_by_field_and_value(field_name: str, field_value: st
 
 
 def count_incomplete_validate_products() -> int:
     """Count the number of incomplete validate_products processes.
 
     :return: The count of incomplete 'validate_products' processes.
     :rtype: int
     """
     return ProcessTable.query.filter(
-        ProcessTable.workflow_name == "validate_products",
+        ProcessTable.workflow_name == "validate_geant_products",
         ProcessTable.last_status != "completed",
     ).count()
@@ -192,13 +192,13 @@ def get_active_subscriptions_by_field_and_value(field_name: str, field_value: st
 
 def count_incomplete_validate_products() -> int:
-    """Count the number of incomplete validate_products processes.
+    """Count the number of incomplete validate_geant_products processes.
 
@@ -192,13 +192,13 @@ def get_active_subscriptions_by_field_and_value(field_name: str, field_value: st
 
-    :return: The count of incomplete 'validate_products' processes.
+    :return: The count of incomplete 'validate_geant_products' processes.
     :rtype: int
     """